hive-bambu.ports

Transport port. Implementations supply their own MQTT signing and serialization.

Transport port. Implementations supply their own MQTT signing and serialization.
raw docstring

dispatchclj

(dispatch transport commands blocked serial sequence-id command params)

Validate command and hand only approved publications to an injected port.

Validate command and hand only approved publications to an injected port.
sourceraw docstring

PrinterTransportcljprotocol

send-requestclj

(send-request this publication)

Send a validated {:topic :payload} publication; answer a result value.

Send a validated {:topic :payload} publication; answer a result value.
source

cljdoc builds & hosts documentation for Clojure/Script libraries