hive-bambu.printer.promote

Pure promotion of printer observations and print authorization.

Pure promotion of printer observations and print authorization.
raw docstring

authorize-printclj/s

(authorize-print blocked observation now request)

Authorize a confirmed print only for a fresh idle fault-free report and safe lines.

Authorize a confirmed print only for a fresh idle fault-free report and safe lines.
sourceraw docstring

merge-reportclj/s

(merge-report previous decoded observed-at)

Merge a sparse print or mc_print delta into an observed report.

Merge a sparse print or mc_print delta into an observed report.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries