Typed stock-profile overrides written only into fresh run directories.
Typed stock-profile overrides written only into fresh run directories.
(derive-profiles! process-path filament-path out overrides)Copy stock JSON into a new run directory with validated overrides and return derived paths.
Copy stock JSON into a new run directory with validated overrides and return derived paths.
(settings)Describe curated settings, their bounds and PrintConfig.cpp source lines.
Describe curated settings, their bounds and PrintConfig.cpp source lines.
(valid-overrides? overrides)Check all overrides against curated bounds or the extracted PrintConfig key set.
Check all overrides against curated bounds or the extracted PrintConfig key set.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |