Transport port. Implementations supply their own MQTT signing and serialization.
Transport port. Implementations supply their own MQTT signing and serialization.
(dispatch transport commands blocked serial sequence-id command params)Validate command and hand only approved publications to an injected port.
Validate command and hand only approved publications to an injected port.
(send-request this publication)Send a validated {:topic :payload} publication; answer a result value.
Send a validated {:topic :payload} publication; answer a result value.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |