Pure promotion of printer observations and print authorization.
Pure promotion of printer observations and print authorization.
(authorize-print blocked observation now request)Authorize a confirmed print only for a fresh idle fault-free report and safe lines.
Authorize a confirmed print only for a fresh idle fault-free report and safe lines.
(merge-report previous decoded observed-at)Merge a sparse print or mc_print delta into an observed report.
Merge a sparse print or mc_print delta into an observed report.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |