Slicer values and validation independent of the CLI boundary.
Slicer values and validation independent of the CLI boundary.
(artifact path)Validate a local model and compute its immutable fingerprint; return a typed refusal on invalid input.
Validate a local model and compute its immutable fingerprint; return a typed refusal on invalid input.
(valid-request? request)Check the slice request schema and model fingerprint.
Check the slice request schema and model fingerprint.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |