hive-bambu.slicer.flatpak

Bounded Flatpak CLI transport with isolated per-slice outputs.

Bounded Flatpak CLI transport with isolated per-slice outputs.
raw docstring

adapterclj

(adapter output-root timeout-ms)

Construct the Flatpak adapter with an output root and finite timeout.

Construct the Flatpak adapter with an output root and finite timeout.
sourceraw docstring

app-idclj

source

availabilityclj

(availability)

Probe the installed Flatpak by exit status without running its GUI.

Probe the installed Flatpak by exit status without running its GUI.
sourceraw docstring

install-commandclj

source

presetsclj

(presets)

List the installed stock BBL printer, process and filament JSON profiles.

List the installed stock BBL printer, process and filament JSON profiles.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries