hive-bambu.slicer.settings

Typed stock-profile overrides written only into fresh run directories.

Typed stock-profile overrides written only into fresh run directories.
raw docstring

allowed-keysclj

source

derive-profiles!clj

(derive-profiles! process-path filament-path out overrides)

Copy stock JSON into a new run directory with validated overrides and return derived paths.

Copy stock JSON into a new run directory with validated overrides and return derived paths.
sourceraw docstring

knobsclj

source

settingsclj

(settings)

Describe curated settings, their bounds and PrintConfig.cpp source lines.

Describe curated settings, their bounds and PrintConfig.cpp source lines.
sourceraw docstring

valid-overrides?clj

(valid-overrides? overrides)

Check all overrides against curated bounds or the extracted PrintConfig key set.

Check all overrides against curated bounds or the extracted PrintConfig key set.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries