Own exactly one launched BambuStudio GUI process per slicer tool.
Own exactly one launched BambuStudio GUI process per slicer tool.
(flatpak-gui)Build the Flatpak GUI process adapter.
Build the Flatpak GUI process adapter.
(close! gui token)Stop only the process identified by an owned token; return whether it exited.
Stop only the process identified by an owned token; return whether it exited.
(launch! gui path)Start a GUI process and return an owned process token.
Start a GUI process and return an owned process token.
(show! viewer path)Close the previously owned GUI and show a sliced 3mf; never touch unowned processes.
Close the previously owned GUI and show a sliced 3mf; never touch unowned processes.
(sliced-archive? path)Require an existing sliced 3mf with BambuStudio slice metadata.
Require an existing sliced 3mf with BambuStudio slice metadata.
(viewer gui)Create a GUI viewer with an injectable process port and private ownership state.
Create a GUI viewer with an injectable process port and private ownership state.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |